"""
模型模块
----------------------------
模型（Model）类。

导入方法：

  >>> from srbpy.model import Model

"""

from srbpy.model.core import Model
from srbpy.model.core import Bridge
from srbpy.model.core import Span
